Usage
bayesglm.fit(x, y, weights = rep(1, nobs),
start = NULL, etastart = NULL,
mustart = NULL, offset = rep(0, nobs), family = binomial(),
coefprior = bic.prior(nobs),
control = glm.control(), intercept = TRUE)Arguments
weights
optional vector of weights to be used in the fitting
process. SHould be NULL or a numeric vector.
start
starting value for coefficients in the linear predictor
etastart
starting values for the linear predictor
mustart
starting values for the vectors of means
offset
a priori known component to be included in the linear
predictor
family
a description of the error distribution and link
function for exponential family;
currently only binomial() is coded.
coefprior
function specifying prior distribution on
coefficients with optionlal hyperparamters leading to marginal
likelihood calculations; options include bic.prior(),aic.prior(), and ic.prior()
control
a list of parameters that control convergence in the
fitting process. See the documentation for
glm.control()
intercept
should an intercept be included in the null model?