intrinsic: Intrinsic Prior Distribution for Coefficients in BMA Models
Description
Creates an object representing the intrinsic prior on g,
a special case of the tCCH mixture of g-priors on
coefficients for BAS.
Usage
intrinsic(n=NULL)
Arguments
n
the sample size; if NULL, the value derived from the data in the call to `bas.glm` will be used.
Value
returns an object of class "prior", with the family "intrinsic"
of class "TCCH" and hyperparameters alpha = 1,
beta = 1, s = 0, r = 1, n = n for the tCCH prior where
theta in the tCCH prior is determined by the model size and sample size.